@@ -37,7 +37,8 @@ typedef enum {
 	MAPI_OPTIONS_FETCH_GAL = 1 <<4,
 	MAPI_OPTIONS_DONT_SUBMIT = 1<<5, 
 	MAPI_OPTIONS_GETBESTBODY = 1<<6,
-	MAPI_OPTIONS_USE_PFSTORE = 1<<7
+	MAPI_OPTIONS_USE_PFSTORE = 1<<7,
+	MAPI_OPTIONS_DONT_OPEN_MESSAGE = 1<<8
 } ExchangeMAPIOptions;
 
 #define MAPI_OPTIONS_FETCH_ALL MAPI_OPTIONS_FETCH_ATTACHMENTS | \
